@@ -841,3 +841,43 @@ extended_stopwords = [
 ]
 
 extended_stopwords = list(set(default_stopwords + extended_stopwords))
+
+punct = [
+    ".",
+    ",",
+    ":",
+    ";",
+    "!",
+    "?",
+    "¿",
+    "¡",
+    "(",
+    ")",
+    "[",
+    "]",
+    "{",
+    "}",
+    "/",
+    "\\",
+    "|",
+    "-",
+    "_",
+    "–",
+    "—",
+    "…",
+    "·",
+    "•",
+    "°",
+    "´",
+    "`",
+    "'",
+    '"',
+    "“",
+    "”",
+    "‘",
+    "’",
+    "«",
+    "»",
+    "‹",
+    "›",
+]
\ No newline at end of file
